export interface LRUCacheOptions<Key extends string, Value> {
    max: number;
    maxAge?: number;
    dispose?: (value: Value, key: Key) => undefined;
}
export interface SetOptions {
    maxAge?: number;
}
export declare const createLRU: <Key extends string, Value>(options: LRUCacheOptions<Key, Value>) => {
    /** Adds a key-value pair to the cache. Updates the value if the key already exists. */
    set: (key: Key, value: Value, options?: SetOptions) => undefined;
    /** Retrieves the value for a given key and moves the key to the most recent position. */
    get: (key: Key) => Value | undefined;
    /** Retrieves the value for a given key without changing its position in the cache. */
    peek: (key: Key) => Value | undefined;
    /** Checks if a key exists in the cache. */
    has: (key: Key) => boolean;
    /** Returns an array of all keys in the cache, from most recent to least recent. */
    keys: () => Key[];
    /** Returns an array of all values in the cache, from most recent to least recent. */
    values: () => Value[];
    /** Returns an array of [key, value] pairs, from most recent to least recent. */
    entries: () => [Key, Value][];
    /** Iterates over each key-value pair in the cache, from most recent to least recent. */
    forEach: (callback: (value: Value, key: Key) => undefined) => undefined;
    /** Deletes a key-value pair from the cache. */
    del: (key: Key) => boolean;
    /** Evicts the oldest item or the specified number of the oldest items from the cache. */
    evict: (size?: number) => undefined;
    /** Clears all key-value pairs from the cache. */
    clear: () => undefined;
    /** Resizes the cache to a new maximum size, evicting items if necessary. */
    resize: (newMax: number) => undefined;
    /** Returns the number of available slots in the cache before reaching the maximum size. */
    available: () => number;
    /** Returns the number of items currently stored in the cache. */
    stored: () => number;
    /** Returns the maximum number of items that can be stored in the cache. */
    maxSize: () => number;
};
